@@ -74,12 +74,11 @@ nroTrain <- function(
                  as.integer(subsample),
                  0.0,
 		 as.double(message),
-                 PACKAGE="Numero" )
-    if(class(res) == "character") stop(res)
+                 PACKAGE="Numero")
+    if(is.character(res)) stop(res)
 
     # Recode missing unit labels.
-    res$layout[which(res$layout == 0)] <- NA
-    res$residuals[which(res$layout == 0)] <- NA
+    res$layout[which(res$layout <= 0)] <- NA
     res$layout <- data.frame(BMC=res$layout, RESIDUAL=res$residuals)
     rownames(res$layout) <- rownames(data)
     
