@@ -4,6 +4,8 @@
 
 #include "abacus.local.h"
 
+#define N_DISTINCT_min 10
+
 /*
  *
  */
@@ -18,15 +20,94 @@ public:
   };
 };
 
-static vector<mdreal> calc_quantiles(const vector<mdreal>&,
-				     const vector<mdreal>&);
+/*
+ *
+ */
+static vector<mdreal>
+prep_bg(unordered_map<mdsize, Group>& groups,
+	const vector<mdreal>& data) {
+
+  /* Original range. */
+  mdreal xmin = statistic(data, "min");
+  mdreal xmax = statistic(data, "max");
+
+  /* Calculate centers. */
+  vector<mdsize> keys;
+  vector<mdreal> weights;
+  vector<mdreal> centers;
+  for(unordered_map<mdsize, Group>::iterator it = groups.begin();
+      it != groups.end(); it++) {    
+    Group& g = it->second;
+    mdreal mu = statistic(g.values, "center");
+    keys.push_back(it->first);
+    weights.push_back(g.values.size());
+    centers.push_back(mu);
+  }
+
+  /* Collect shifted values. */
+  vector<mdreal> bg;
+  mdreal origin = statistic(centers, weights, "center");
+  for(mdsize k = 0; k < keys.size(); k++) {
+    Group& g = groups[keys[k]];
+    vector<mdreal>& vals = g.values;
+    for(mdsize i = 0; i < vals.size(); i++) {
+      mdreal x = (vals[i] - centers[k] + origin);
+      if(x < xmin) continue;
+      if(x > xmax) continue;
+      bg.push_back(x);
+    }
+  }
+  
+  /* Sort values. */
+  sort(bg.begin(), bg.end());
+  return bg;
+}
+
+/*
+ * X must be sorted and must contain only valid values.
+ */
+static vector<mdreal>
+calc_quantiles(const vector<mdreal>& bg, const vector<mdreal>& q) {
+  mdsize n = bg.size();
+  vector<mdreal> y = q;
+  mdreal rlnan = medusa::rnan();
+  if(n < 2) panic("Unusable background.", __FILE__, __LINE__);
+
+  /* Check that there is enough diversity. */
+  unordered_set<mdreal> distinct(q.begin(), q.end());
+  distinct.erase(rlnan);
+  if(distinct.size() < N_DISTINCT_min)
+    return vector<mdreal>(q.size(), rlnan);
+
+  /* Transform quantiles to values. */
+  for(mdsize i = 0; i < q.size(); i++) {
+    double qi = q[i];
+    if(qi == rlnan) continue;
+    if(qi < 0.0) panic("Invalid quantile.", __FILE__, __LINE__);
+    if(qi > 1.0) panic("Invalid quantile.", __FILE__, __LINE__);
+    
+    /* Determine quantile indices. */
+    mdsize a = (mdsize)(qi*(n - 1));
+    mdsize b = (a + 1);
+    if(b >= n) b = (n - 1);
+    if(a == b) {
+      y[i] = bg[a];
+      continue;
+    }
+    
+    /* Interpolate between indices. */
+    double d = (qi*(n - 1) - a);
+    y[i] = ((1.0 - d)*(bg[a]) + d*(bg[b]));
+  }
+  return y;
+}
 
 /*
  *
  */
 vector<mdreal>
 abacus::destratify(const vector<mdreal>& x, const vector<mdsize>& g) {
-  mdreal rl_nan = medusa::rnan();
+  mdreal rlnan = medusa::rnan();
 
   /* Check inputs. */
   if(x.size() != g.size())
@@ -35,22 +116,15 @@ abacus::destratify(const vector<mdreal>& x, const vector<mdsize>& g) {
   /* Divide values into groups. */
   unordered_map<mdsize, Group> groups;
   for(mdsize i = 0; i < x.size(); i++) {
-    if(x[i] == rl_nan) continue;
+    if(x[i] == rlnan) continue;
     groups[g[i]].add(i, x[i]);
   }
   if(groups.size() < 2) return x;
 
   /* Collect background. */
-  vector<mdreal> y;
-  for(mdsize i = 0; i < x.size(); i++) {
-    if(x[i] == rl_nan) continue;
-    y.push_back(x[i]);
-  }
+  vector<mdreal> y = prep_bg(groups, x);
   if(y.size() < 2) return x;
 
-  /* Sort background. */
-  sort(y.begin(), y.end());
-
   /* Convert group values to global values. */
   unordered_map<mdsize, Group>::iterator pos;
   for(pos = groups.begin(); pos != groups.end(); pos++) {
@@ -69,33 +143,3 @@ abacus::destratify(const vector<mdreal>& x, const vector<mdsize>& g) {
   return y;
 }
 
-/*
- * X must be sorted and must contain only valid values.
- */
-vector<mdreal>
-calc_quantiles(const vector<mdreal>& x, const vector<mdreal>& q) {
-  mdsize n = x.size();
-  vector<mdreal> y = q;
-  mdreal rl_nan = medusa::rnan();
-  if(n < 2) panic("Invalid input.", __FILE__, __LINE__);
-  for(mdsize i = 0; i < q.size(); i++) {
-    double qi = q[i];
-    if(qi == rl_nan) continue;
-    if(qi < 0.0) panic("Invalid quantile.", __FILE__, __LINE__);
-    if(qi > 1.0) panic("Invalid quantile.", __FILE__, __LINE__);
-    
-    /* Determine quantile indices. */
-    mdsize a = (mdsize)(qi*(n - 1));
-    mdsize b = (a + 1);
-    if(b >= n) b = (n - 1);
-    if(a == b) {
-      y[i] = x[a];
-      continue;
-    }
-    
-    /* Interpolate between indices. */
-    double d = (qi*(n - 1) - a);
-    y[i] = ((1.0 - d)*x[a] + d*x[b]);
-  }
-  return y;
-}
